@@ -17,11 +17,15 @@
 #' @importFrom grDevices col2rgb
 #' @export
 #' @return data.frame
+#'
 makedfMarkColorMycolors<- function(markNames, mycolors, colorstoremove=NULL, defaultStyleMark="square"){
+
   dfMarkColor<-idiogramFISH::dfMarkColor
+
   message(crayon::green(paste("By default 5S are plotted as dots, to change this behavior make your own dfMarkColor data.frame") )
           ) # m
-  dfMarkColor[which(dfMarkColor$style %in% "square"),]$style<-defaultStyleMark
+
+  tryCatch(dfMarkColor[which(dfMarkColor$style %in% "square"),]$style<-defaultStyleMark, error=function(e) "")
 
   mycolors<-mycolors[!mycolors %in% colorstoremove]
 
@@ -31,17 +35,31 @@ makedfMarkColorMycolors<- function(markNames, mycolors, colorstoremove=NULL, def
   } )]
 
   dfMarkColorNew<-data.frame(markName=markNames)
-  dfMarkColorNew$markColor<-NA
+  dfMarkColorNew$markNameNP <- dfMarkColorNew$markName
+  dfMarkColorNew$markNameNP <- gsub("^inProtein","",dfMarkColorNew$markNameNP)
+  dfMarkColorNew$markColor <- NA
+
+  vecNP<-unique(dfMarkColorNew$markNameNP)
+  lenmandf<-length(vecNP)
 
-  lenmandf<-nrow(dfMarkColorNew)
   if(length(mycolors)<lenmandf){
     message(crayon::red(paste("Not enough colors in mycolor parameter, will be recycled") ) )
     repF<-ceiling(lenmandf/length(mycolors) )
     mycolors<-rep(mycolors,repF)
   }
-  dfMarkColorNew$markColor<-mycolors[1:lenmandf]
-  dfMarkColorNew$style<-dfMarkColor$style[match(toupper(dfMarkColorNew$markName),toupper(dfMarkColor$markName) )]
+
+  mycolors <- mycolors[1:lenmandf]
+  names(mycolors)<- vecNP
+
+  dfMarkColorNew$markColor <- mycolors[ match( dfMarkColorNew$markNameNP,names(mycolors)  ) ]
+
+  dfMarkColorNew$style<-dfMarkColor$style[match(toupper(dfMarkColorNew$markNameNP),toupper(dfMarkColor$markName) )]
+
   dfMarkColorNew$style[which(is.na(dfMarkColorNew$style))]<-defaultStyleMark
+
+  tryCatch(dfMarkColorNew[which(dfMarkColorNew$markName %in%
+                         grep("inProtein",dfMarkColorNew$markName,value=TRUE) ),]$style<-"inProtein"
+           ,error=function(e){""} )
   return(dfMarkColorNew)
 }
 
